@@ -1,6 +1,6 @@
 package Mason;
 BEGIN {
-  $Mason::VERSION = '2.04';
+  $Mason::VERSION = '2.05';
 }
 use Mason::Interp;
 use Mason::PluginManager;
@@ -38,13 +38,19 @@ Mason - Powerful, high-performance templating for the web and beyond
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 SYNOPSIS
 
+  foo.mc:
     % my $name = "Mason";
     Hello world! Welcome to <% $name %>.
 
+  #!/usr/local/bin/perl
+  use Mason;
+  my $mason = Mason->new(comp_root => '...');
+  print $mason->run('/foo')->output;
+
 =head1 DESCRIPTION
 
 Mason is a powerful Perl-based templating system, designed to generate dynamic
