@@ -1,6 +1,6 @@
 package Mason::Request;
 BEGIN {
-  $Mason::Request::VERSION = '2.04';
+  $Mason::Request::VERSION = '2.05';
 }
 use Carp;
 use File::Basename;
@@ -247,7 +247,7 @@ method catch_abort ($code) {
 }
 
 method match_request_path ($request_path) {
-    return $self->interp->match_request_path->( $self, $request_path );
+    $self->interp->match_request_path->( $self, $request_path );
 }
 
 method run () {
@@ -255,6 +255,7 @@ method run () {
     # Get path and either hash or hashref of arguments
     #
     my $request_path = shift;
+    $self->interp->_assert_absolute_path($request_path);
     my $request_args;
     if ( @_ == 1 && reftype( $_[0] ) eq 'HASH' ) {
         $request_args = shift;
@@ -293,8 +294,7 @@ method run () {
     # Turn request path into a page component
     #
   match_request_path:
-    my $page_path = $self->match_request_path($request_path)
-      or $self->request_path_not_found($request_path);
+    my $page_path  = $self->match_request_path($request_path);
     my $page_compc = $self->interp->load($page_path);
     $log->debugf( "starting request with component '%s'", $page_path )
       if $log->is_debug;
@@ -332,15 +332,6 @@ method run () {
     return $self->result;
 }
 
-method request_path_not_found ($path) {
-    Mason::Exception::TopLevelNotFound->throw(
-        error => sprintf(
-            "could not find component for request path '%s' - component root is [%s]\n",
-            $path, join( ", ", @{ $self->interp->comp_root } )
-        )
-    );
-}
-
 method with_tied_print ($code) {
     local *TH;
     tie *TH, 'Mason::TieHandle';
@@ -416,7 +407,7 @@ Mason::Request - Mason Request Class
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -586,14 +577,14 @@ the previously chosen page component(s) do not exist.
 
 For example, if the following components exist:
 
-    /news/sports.m
-    /news/dhandler.m
-    /dhandler.m
+    /news/sports.mc
+    /news/dhandler.mc
+    /dhandler.mc
 
 then a request for path C</news/sports> will initially resolve to
-C</news/sports.m>.  A call to C<< $m->decline >> would restart the request and
-resolve to C</news/dhandler.m>, a second C<< $m->decline >> would resolve to
-C</dhandler.m>, and a third would throw a "not found" error.
+C</news/sports.mc>.  A call to C<< $m->decline >> would restart the request and
+resolve to C</news/dhandler.mc>, a second C<< $m->decline >> would resolve to
+C</dhandler.mc>, and a third would throw a "not found" error.
 
 =for html <a name="flush_buffer" />
 
@@ -673,7 +664,7 @@ Returns the page component originally called in the request.
 
 Returns the remainder of the request path beyond the path of the page
 component, with no leading slash. e.g. If a request for '/foo/bar/baz' resolves
-to "/foo.m", the path_info is "bar/baz". For an exact match, it will contain
+to "/foo.mc", the path_info is "bar/baz". For an exact match, it will contain
 the empty string (never undef), so you can determine whether there's a
 path_info with
 
