@@ -1,6 +1,6 @@
 package Mason::Types;
 BEGIN {
-  $Mason::Types::VERSION = '2.04';
+  $Mason::Types::VERSION = '2.05';
 }
 use Moose::Util::TypeConstraints;
 use strict;
@@ -19,6 +19,6 @@ subtype 'Mason::Types::RegexpRefOrStr' => as 'RegexpRef';
 coerce 'Mason::Types::RegexpRefOrStr' => from 'Str' => via { qr/$/ };
 
 subtype 'Mason::Types::Autoextend' => as 'ArrayRef[Str]';
-coerce 'Mason::Types::Autoextend' => from 'Bool' => via { $_ ? [ '.pm', '.m' ] : [] };
+coerce 'Mason::Types::Autoextend' => from 'Bool' => via { $_ ? [ '.mp', '.mc' ] : [] };
 
 1;
