@@ -1,15 +1,15 @@
 package Mason::t::Cache;
 BEGIN {
-  $Mason::t::Cache::VERSION = '2.04';
+  $Mason::t::Cache::VERSION = '2.05';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
 __PACKAGE__->default_plugins( [ '@Default', 'Cache' ] );
 
-sub test_cache_defaults : Test(2) {
+sub test_cache_defaults : Tests {
     my $self = shift;
     $self->run_test_in_comp(
-        path => '/cache/defaults.m',
+        path => '/cache/defaults.mc',
         test => sub {
             my $comp = shift;
             is( $comp->cache->label,     'File',             'cache->label' );
@@ -18,10 +18,10 @@ sub test_cache_defaults : Test(2) {
     );
 }
 
-sub test_cache_method : Test(1) {
+sub test_cache_method : Tests {
     my $self = shift;
     $self->test_comp(
-        path => '/cache.m',
+        path => '/cache.mc',
         src  => '
 <%shared>
 $.count => 0
@@ -39,7 +39,7 @@ namespace: <% $.cache->namespace %>
 <% $.getset("foo") %>
 ',
         expect => '
-namespace: /cache.m
+namespace: /cache.mc
 foo1
 
 bar2
@@ -51,7 +51,7 @@ foo1
     );
 }
 
-sub test_cache_filter : Test(2) {
+sub test_cache_filter : Tests {
     my $self = shift;
 
     $self->test_comp(
