@@ -1,10 +1,10 @@
 package Mason::t::Filters;
 BEGIN {
-  $Mason::t::Filters::VERSION = '2.04';
+  $Mason::t::Filters::VERSION = '2.05';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
-sub test_filters : Test(1) {
+sub test_filters : Tests {
     my $self = shift;
     $self->test_comp(
         src => '
@@ -32,7 +32,7 @@ hello world!
     );
 }
 
-sub test_filter_block : Test(1) {
+sub test_filter_block : Tests {
     my $self = shift;
     $self->test_comp(
         src => '
@@ -62,7 +62,7 @@ print(uc($content));
     );
 }
 
-sub test_lexical : Test(1) {
+sub test_lexical : Tests {
     my $self = shift;
     $self->test_comp(
         src => <<'EOF',
@@ -75,7 +75,7 @@ EOF
     );
 }
 
-sub test_repeat : Test(1) {
+sub test_repeat : Tests {
     my $self = shift;
     $self->test_comp(
         src => <<'EOF',
@@ -92,7 +92,7 @@ EOF
     );
 }
 
-sub test_nested : Test(1) {
+sub test_nested : Tests {
     my $self = shift;
     $self->test_comp(
         src => <<'EOF',
@@ -118,7 +118,7 @@ EOF
     );
 }
 
-sub test_misc_standard_filters : Test(2) {
+sub test_misc_standard_filters : Tests {
     my $self = shift;
 
     $self->test_comp(
@@ -157,7 +157,7 @@ EOF
     );
 }
 
-sub test_around : Test(1) {
+sub test_around : Tests {
     my $self = shift;
     $self->test_comp(
         src => <<'EOF',
