@@ -1,10 +1,10 @@
 package Mason::t::Sanity;
 BEGIN {
-  $Mason::t::Sanity::VERSION = '2.04';
+  $Mason::t::Sanity::VERSION = '2.05';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
-sub test_ok : Test(1) {
+sub test_ok : Tests {
     my $self = shift;
     $self->test_comp( src => '2 + 2 = <% 2 + 2 %>', expect => '2 + 2 = 4' );
 }
