@@ -1,6 +1,6 @@
 package Mason::t::StaticSource;
 BEGIN {
-  $Mason::t::StaticSource::VERSION = '2.04';
+  $Mason::t::StaticSource::VERSION = '2.05';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 use Mason::Util qw(write_file touch_file);
@@ -10,11 +10,11 @@ sub setup : Test(setup) {
 
     $self->setup_dirs();
     $self->add_comp(
-        path => "/ss/remove_component.m",
+        path => "/ss/remove_component.mc",
         src  => "I will be removed.\n",
     );
     $self->add_comp(
-        path => "/ss/change_component.m",
+        path => "/ss/change_component.mc",
         src  => "I will be changed.\n",
     );
 }
@@ -31,71 +31,71 @@ sub remove_comp {
     unlink($source_file);
 }
 
-sub test_change_no_ss : Test(2) {
+sub test_change_no_ss : Tests {
     my $self = shift;
     $self->test_comp(
-        src    => '<& /ss/change_component.m &>',
+        src    => '<& /ss/change_component.mc &>',
         expect => 'I will be changed.',
     );
     sleep(1);    # Make sure timestamp changes
-    $self->write_comp( "/ss/change_component.m", "I have changed!\n" );
+    $self->write_comp( "/ss/change_component.mc", "I have changed!\n" );
     $self->test_comp(
-        src    => '<& /ss/change_component.m &>',
+        src    => '<& /ss/change_component.mc &>',
         expect => 'I have changed!',
     );
 }
 
-sub test_change_and_touch_ss : Test(3) {
+sub test_change_and_touch_ss : Tests {
     my $self       = shift;
     my $touch_file = $self->temp_dir . "/purge.dat";
     $self->setup_interp( static_source => 1, static_source_touch_file => $touch_file );
     $self->test_comp(
-        src    => '<& /ss/change_component.m &>',
+        src    => '<& /ss/change_component.mc &>',
         expect => 'I will be changed.',
     );
     sleep(1);    # Make sure timestamp changes
-    $self->interp->load('/ss/change_component.m');
-    $self->write_comp( "/ss/change_component.m", "I have changed!\n" );
+    $self->interp->load('/ss/change_component.mc');
+    $self->write_comp( "/ss/change_component.mc", "I have changed!\n" );
     $self->test_comp(
-        src    => '<& /ss/change_component.m &>',
+        src    => '<& /ss/change_component.mc &>',
         expect => 'I will be changed.',
     );
     touch_file($touch_file);
     $self->test_comp(
-        src    => '<& /ss/change_component.m &>',
+        src    => '<& /ss/change_component.mc &>',
         expect => 'I have changed!',
     );
 }
 
-sub test_remove_no_ss : Test(2) {
+sub test_remove_no_ss : Tests {
     my $self = shift;
     $self->test_comp(
-        src    => '<& /ss/remove_component.m &>',
+        src    => '<& /ss/remove_component.mc &>',
         expect => 'I will be removed.',
     );
-    $self->remove_comp("/ss/remove_component.m");
+    $self->remove_comp("/ss/remove_component.mc");
     $self->test_comp(
-        src          => '<& /ss/remove_component.m &>',
+        src          => '<& /ss/remove_component.mc &>',
         expect_error => qr/could not find component/
     );
 }
 
-sub test_remove_and_touch_ss : Test(3) {
+sub test_remove_and_touch_ss : Tests {
     my $self       = shift;
     my $touch_file = $self->temp_dir . "/purge.dat";
     $self->setup_interp( static_source => 1, static_source_touch_file => $touch_file );
     $self->test_comp(
-        src    => '<& /ss/remove_component.m &>',
+        src    => '<& /ss/remove_component.mc &>',
         expect => 'I will be removed.',
     );
-    $self->remove_comp("/ss/remove_component.m");
+    $self->remove_comp("/ss/remove_component.mc");
     $self->test_comp(
-        src    => '<& /ss/remove_component.m &>',
+        src    => '<& /ss/remove_component.mc &>',
         expect => 'I will be removed.',
     );
     touch_file($touch_file);
     $self->test_comp(
-        src          => '<& /ss/remove_component.m &>',
+        src          => '<& /ss/remove_component.mc &>',
         expect_error => qr/could not find component/
     );
 }
